'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _immutable = require('immutable');

var _redux = require('redux');

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

/**
 * A high level, testable, store 'maker'.
 * Intended to make it easy to create a store instance from
 * a pre-defined config as well as dynamically imported data.
 * Also makes the creation of multiple stores easy.
 *
 * import storeMaker from 'Store'
 *
 * // Create a storeMaker instnace
 * let Store = storeMaker()
 *
 * // build up a store
 * Store.addReducer(...)
 * Store.addMiddleware(...)
 *
 * // get a Redux store instance
 * let store = Store()
 */

exports.default = function () {
  var reducers = (0, _immutable.Map)();
  var middlewares = (0, _immutable.List)();

  var create = function create() {
    var initial = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    var reducer = (0, _redux.combineReducers)(reducers.toJS());
    var enhancers = _redux.applyMiddleware.apply(undefined, _toConsumableArray(middlewares.toJS()));

    if (process.env.NODE_ENV !== 'production') {
      enhancers = (0, _redux.compose)(enhancers, window.devToolsExtension ? window.devToolsExtension() : function (f) {
        return f;
      });
    }

    return (0, _redux.createStore)(reducer, initial, enhancers);
  };

  // simple getters for testing.
  create._getReducers = function () {
    return reducers;
  };
  create._getMiddlewares = function () {
    return middlewares;
  };

  create.addReducer = function (name, r) {
    reducers = reducers.set(name, r);
    return reducers;
  };

  create.addMiddleware = function (mw) {
    if (_immutable.List.isList(mw) || Array.isArray(mw)) {
      middlewares = middlewares.concat(mw);
    } else {
      middlewares = middlewares.push(mw);
    }

    return middlewares;
  };

  return create;
};

module.exports = exports['default'];