'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.name = exports.desc = undefined;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _constants = require('../../constants');

var _utils = require('../../utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var desc = exports.desc = 'Generate a rj command module';
var name = exports.name = 'cmd <name>';

var builder = exports.builder = {
  force: {
    default: false,
    alias: 'f',
    type: 'boolean',
    describe: 'Overwrite existing command of same name'
  },
  desc: {
    alias: 'd',
    type: 'string',
    describe: 'Command description'
  },
  alias: {
    alias: 'a',
    type: 'string',
    describe: 'Command alias'
  }
};

var handler = exports.handler = function handler(argv) {
  var rjRoot = (0, _utils.findRjRoot)();

  if (!rjRoot) {
    throw Error('Unable to find root of rj project!!!');
  }

  var cDir = _path2.default.join(rjRoot, _constants.cmdDir);

  if (!_fs2.default.existsSync(cDir)) {
    throw Error('Unable to access the cmds dir at', cDir);
  }

  var cmdPath = _path2.default.join(cDir, argv.name + '.js');
  if (!argv.f && _fs2.default.existsSync(cmdPath)) {
    throw Error('Cmd module already exists. Use --force if you wish to over write it!');
  }

  var cmd = '';
  if (argv.alias) {
    cmd += 'export const alias = \'' + argv.alias + '\'';
  }

  cmd += '\nexport const desc = \'' + (argv.desc || '') + '\'\nexport const name = \'' + argv.name + '\'\n\nexport const builder = {}\nexport const handler = (argv) => {\n  console.log(\'' + argv.name + '\', argv)\n}\n';

  var fd = _fs2.default.openSync(cmdPath, 'w');
  _fs2.default.writeSync(fd, cmd);
  _fs2.default.closeSync(fd);
};