'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.name = exports.desc = undefined;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// export let desc = 'Create a JS module from the given path(s)'
var desc = exports.desc = false;
var name = exports.name = 'mod';

var pathParts = function pathParts(mPath) {
  if (!mPath) {
    return [];
  }

  var finfo = _path2.default.parse(mPath);
  return pathParts(finfo.dir).concat([finfo.name]);
};

function mkMod(mPath) {
  var cPath = _path2.default.normalize(mPath);

  if (_path2.default.isAbsolute(cPath)) {
    throw Error('Only relative paths are allowed, ' + mPath + ' is an invalid path.');
  }

  // Break the path into parts so we can easily traverse down it.
  var parts = pathParts(cPath);

  if (_fs2.default.existsSync(cPath)) {
    var statData = _fs2.default.statSync(cPath);
    if (!statData.isDirectory()) {
      // console.warn(`${mPath} exists and is not a directory.`)
      // Don't deal with the last node if it's not a directory
      parts = parts.slice(0, -1);
    }
  }

  function mkdirp(p, parts) {
    if (!_fs2.default.existsSync(p)) {
      _fs2.default.mkdirSync(p);
    }

    var indx = _path2.default.join(p, 'index.js');
    if (!_fs2.default.existsSync(indx)) {
      _fs2.default.closeSync(_fs2.default.openSync(indx, 'w'));
    }

    if (parts.length === 0) {
      return;
    }

    mkdirp(_path2.default.join(p, parts[0]), parts.slice(1));
  }

  mkdirp(parts[0], parts.slice(1));
}

var builder = exports.builder = {
  quiet: {
    default: false,
    alias: 'q',
    type: 'boolean'
  }
};
var handler = exports.handler = function handler(argv) {
  if (!argv._) {
    return;
  }

  if (argv._[0] === 'mod') {
    argv._.slice(1).forEach(function (mod) {
      mkMod(mod);
      if (!argv.q) {
        console.log('Created mod at path', mod);
      }
    });
  }
};