'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getModInfo = exports.MOD_IS_FAT = exports.MOD_IS_SIMPLE = exports.MOD_IS_FILE = exports.MOD_IS_NOT = undefined;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var MOD_IS_NOT = exports.MOD_IS_NOT = Symbol.for('MOD_IS_NOT'); // The module is a directory but has no index.js
var MOD_IS_FILE = exports.MOD_IS_FILE = Symbol.for('MOD_IS_FILE'); // The module is a standalone file
var MOD_IS_SIMPLE = exports.MOD_IS_SIMPLE = Symbol.for('MOD_IS_SIMPLE'); // The module is a directory with _only one file and that file is index.js_
var MOD_IS_FAT = exports.MOD_IS_FAT = Symbol.for('MOD_IS_FAT'); // The module is a directory with files that aren't index.js and the dir has an index.js

var determineModType = function determineModType(mod) {
  if (!mod.isDir) {
    return MOD_IS_FILE;
  }

  var hasIndex = mod.files.indexOf('index.js') !== -1;

  if (mod.files.length === 1 && hasIndex) {
    return MOD_IS_SIMPLE;
  }

  if (mod.files.length > 1 && hasIndex) {
    return MOD_IS_FAT;
  }

  return MOD_IS_NOT;
};

var getModInfo = exports.getModInfo = function getModInfo(modPath) {
  var statData = _fs2.default.statSync(modPath);

  var subs = [];
  var files = [];
  var isDir = statData.isDirectory();

  if (isDir) {
    files = _fs2.default.readdirSync(modPath);
    // console.log('FILES:', files)

    for (var i = 0; i < files.length; i++) {
      var fname = _path2.default.join(modPath, files[i]);
      subs.push(getModInfo(fname));
    }
  }

  var res = {
    'path': modPath,
    'name': _path2.default.basename(modPath),
    'isDir': isDir,
    'files': files,
    'subs': subs
  };

  if (!isDir) {
    // truncate the name up to the first '.'
    var idx = res.name.indexOf('.');
    if (idx !== -1) {
      res.name = res.name.slice(0, idx);
    }
  }

  res.modType = determineModType(res);

  if (res.modType !== MOD_IS_NOT) {
    res.reqObj = require(modPath);
    res.reqObjKeys = Object.keys(res.reqObj);
    // console.log('REQUIRE:', modPath, res.reqObj)
  }

  return res;
};